==> ejc-print-api-3.0.0-20200511.083208-3-sources.jar: com/ejianc/foundation/print/vo/TemplateVO.java <==
package com.ejianc.foundation.print.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import org.springframework.stereotype.Component;

@Component
public class TemplateVO extends BaseVO {

    public static final String TEMPLATE_TYPE_CUSTOM_FORM = "1";
    public static final String TEMPLATE_TYPE_COMMON = "2";

    /**
     * 模板编码
     */
    private String templateCode;
    /**
     * 模板名称
     */
    private String templateName;
    /**
     * 模板对应业务对象Id
     */
    private Long boId;

    /**
     * 模板内容
     */
    private String content;

    /**
     * 模板类型：1-自定义表单模板，2-普通模板
     */
    private String templateType;

    /**
     * 模板字段间关系
     */
    private String fieldRelationJson;

    /**
     * 数据查询Url
     */
    private String detailUrl;

    public String getTemplateCode() {
        return templateCode;
    }

    public void setTemplateCode(String templateCode) {
        this.templateCode = templateCode;
    }

    public String getTemplateName() {
        return templateName;
    }

    public void setTemplateName(String templateName) {
        this.templateName = templateName;
    }

    public Long getBoId() {
        return boId;
    }

    public void setBoId(Long boId) {
        this.boId = boId;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getTemplateType() {
        return templateType;
    }

    public void setTemplateType(String templateType) {
        this.templateType = templateType;
    }

    public String getFieldRelationJson() {
        return fieldRelationJson;
    }

    public void setFieldRelationJson(String fieldRelationJson) {
        this.fieldRelationJson = fieldRelationJson;
    }

    public String getDetailUrl() {
        return detailUrl;
    }

    public void setDetailUrl(String detailUrl) {
        this.detailUrl = detailUrl;
    }
}

==> ejc-print-api-3.0.0-20200512.075554-4-sources.jar: com/ejianc/foundation/print/vo/TemplateVO.java <==
package com.ejianc.foundation.print.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import org.springframework.stereotype.Component;

@Component
public class TemplateVO extends BaseVO {

    public static final String TEMPLATE_TYPE_CUSTOM_FORM = "1";
    public static final String TEMPLATE_TYPE_COMMON = "2";
    private static final long serialVersionUID = 7990232943880627089L;

    /**
     * 模板编码
     */
    private String templateCode;
    /**
     * 模板名称
     */
    private String templateName;
    /**
     * 模板对应业务对象Id
     */
    private Long boId;

    /**
     * 模板内容
     */
    private String content;

    /**
     * 模板类型：1-自定义表单模板，2-普通模板
     */
    private String templateType;

    /**
     * 模板字段间关系
     */
    private String fieldRelationJson;

    /**
     * 数据查询Url
     */
    private String detailUrl;

    /**
     * 单据类型主键Id
     */
    private Long billTypeId;

    public String getTemplateCode() {
        return templateCode;
    }

    public void setTemplateCode(String templateCode) {
        this.templateCode = templateCode;
    }

    public String getTemplateName() {
        return templateName;
    }

    public void setTemplateName(String templateName) {
        this.templateName = templateName;
    }

    public Long getBoId() {
        return boId;
    }

    public void setBoId(Long boId) {
        this.boId = boId;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getTemplateType() {
        return templateType;
    }

    public void setTemplateType(String templateType) {
        this.templateType = templateType;
    }

    public String getFieldRelationJson() {
        return fieldRelationJson;
    }

    public void setFieldRelationJson(String fieldRelationJson) {
        this.fieldRelationJson = fieldRelationJson;
    }

    public String getDetailUrl() {
        return detailUrl;
    }

    public void setDetailUrl(String detailUrl) {
        this.detailUrl = detailUrl;
    }

    public Long getBillTypeId() {
        return billTypeId;
    }

    public void setBillTypeId(Long billTypeId) {
        this.billTypeId = billTypeId;
    }
}
